<?php

namespace Ems\Controllers;

use Ems\Services\EscalaService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;

class EscalaController {
    /** @var EscalaService */
    protected $escalaService;

    public function __construct(
        EscalaService $escalaService
    ) {
        $this->escalaService = $escalaService;
    }

    public function getEscalaTrab(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $dtMesCompetencia = (string) ($row['DTMESCOMPETENCIA'] ?? '');

            $escalas = $this->escalaService->getEscalaTrab($dtMesCompetencia);

            $response->addDataSet(new DataSet('getEscalaTrab', $escalas));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getTurnos(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $nrEscala = (int) $row['NRESCALATRABM'];

            $turnos = $this->escalaService->getTurnos($nrEscala);

            $response->addDataSet(new DataSet('getTurnos', $turnos));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
}
