<?php
namespace Ems\Repository;

use Doctrine\ORM\EntityManager;
use Doctrine\DBAL\Connection;

class OperadorRepository {

    /** @var Connection */
    protected $connection;

    public function __construct(
        EntityManager $entityManager
    ) {
        $this->connection = $entityManager->getConnection();
    }

    public function getPerfisDeAcesso(array $params): array {
        $sql = <<<SQL
            SELECT PERFPARC.NRPERFILACESSO
            FROM PERFACESSPARC PERFPARC
            WHERE PERFPARC.NRPARCNEGOCIO = (
                SELECT OPER.NRPARCNEGOCIO
                FROM OPERADOR OPER
                WHERE OPER.CDOPERADOR = :P_CDOPERADOR
                  AND OPER.NRORG = PERFPARC.NRORG
            )
              AND PERFPARC.NRORG = :P_NRORG
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $perfis = $std->fetchAll();

        return $perfis;
    }
    
    public function getOperadoresDp($nrorg) {
        $sql = "
               SELECT OP.* FROM OPERADOR OP
        JOIN PERFACESSPARC PA 
            ON OP.NRORG = PA.NRORG
            AND OP.NRPARCNEGOCIO = PA.NRPARCNEGOCIO
        WHERE OP.NRORG = :P_NRORG 
            AND NRPERFILACESSO IN (SELECT NRPERFACESSADM
              FROM GPE_PARAMORG 
             WHERE NRORG = :P_NRORG)
      ";

      $resultado = $this->connection->fetchAll($sql, array(
          "P_NRORG" => $nrorg
      ));
      
      return $resultado;
    }

    public function get(
        int $nrOrg,
        string $cdOperador
    ) {
        $sql = <<< SQL
            SELECT
                *
            FROM
                OPERADOR
            WHERE
                CDOPERADOR = :P_CDOPERADOR AND
                NRORG = :P_NRORG
SQL;

        $params = [
            'P_NRORG'       => $nrOrg,
            'P_CDOPERADOR'  => $cdOperador,
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $operador = $std->fetch();

        return $operador;
    }

    public function insert(
        array $params
    ): void {
        $sql = <<<SQL
            INSERT INTO OPERADOR (
                CDOPERADOR,         CDPAIS,                 SGESTADO,
                CDMUNICIPIO,        NMOPERADOR,             NMACESSO,
                NMCOMPLOPER,        DTNASCIMENTO,           DSENDEOPER,
                NMBAIROPER,         NRCEPOPER,              NRTELEOPER,
                CDSENHOPER,         DTULTATUOPER,           CDCLIENTE,
                NROPERREDE,         CDEMPRESA,              CDFUNC,
                NRRAMALOPER,        IDLIGEXTOPER,           IDSENHVARDIA,
                DSEMAILOPER,        IDOPERMASTER,           IDOPERACESSO,
                CDSENEMAILOP,       IDOPERATIVO,            CDSETOR,
                IDFUNINIOPER,       HRINIAGEOPER,           HRFIMAGEOPER,
                CDCARGO,            DTULTATUSENH,           IDTPOPERADOR,
                IDSTATUSENHA,       DTULTACESOPER,          NRCELULAROPER,
                IDATUOPERADOR,      CDBANCOPER,             CDAGENOPER,
                CDCCOROPER,         CDOPERESPLIBSEN,        NRORG,
                DTINCLUSAO,         DTULTATU,               NRORGINCLUSAO,
                CDOPERINCLUSAO,     NRORGULTATU,            CDOPERULTATU,
                NRPARCNEGOCIO,      CDSENHAOPERWEB,         NRPERFILSELECIONADO,
                NRORGSELECIONADA,   CDFILIALSELECIONADA,    CDPROCHABLANOPE,
                CDPROCHABAPROPE,    CDPROCHABFECOPE,        IDCADPRAPROVORE,
                IDCADPRPROCEORE,    IDATIVO,                NRORGTRAB,
                NRESTRUTTRAB,       NRORGFILIAL,            IDIDIOMA,
                SGOPERADOR,         CDSENHAOPERMD5,         DSHASHALTERASENHA,
                DSEMAILOPER_BKP,    DSCRIPTORECSENHA,       IDCHEFERECEITAM,
                USR_NRORDEMSETOR,   NROPERREDE_BKP,         IDOPERSAAS,
                DSIMAGEMOPER,       NRORGOPER,              IDOPERMASTERZMART,
                IDOPERMASTERCP,     CDSENHAOPERSUP,         NRORGSUP,
                DTLIMACESSOSUP
            ) VALUES (
                :CDOPERADOR,        :CDPAIS,                :SGESTADO,
                :CDMUNICIPIO,       :NMOPERADOR,            :NMACESSO,
                :NMCOMPLOPER,       :DTNASCIMENTO,          :DSENDEOPER,
                :NMBAIROPER,        :NRCEPOPER,             :NRTELEOPER,
                :CDSENHOPER,        SYSDATE,                :CDCLIENTE,
                :NROPERREDE,        :CDEMPRESA,             :CDFUNC,
                :NRRAMALOPER,       :IDLIGEXTOPER,          :IDSENHVARDIA,
                :DSEMAILOPER,       :IDOPERMASTER,          :IDOPERACESSO,
                :CDSENEMAILOP,      :IDOPERATIVO,           :CDSETOR,
                :IDFUNINIOPER,      :HRINIAGEOPER,          :HRFIMAGEOPER,
                :CDCARGO,           :DTULTATUSENH,          :IDTPOPERADOR,
                :IDSTATUSENHA,      :DTULTACESOPER,         :NRCELULAROPER,
                :IDATUOPERADOR,     :CDBANCOPER,            :CDAGENOPER,
                :CDCCOROPER,        :CDOPERESPLIBSEN,       :NRORG,
                SYSDATE,            SYSDATE,                :NRORGINCLUSAO,
                :CDOPERINCLUSAO,    :NRORGULTATU,           :CDOPERULTATU,
                :NRPARCNEGOCIO,     :CDSENHAOPERWEB,        :NRPERFILSELECIONADO,
                :NRORGSELECIONADA,  :CDFILIALSELECIONADA,   :CDPROCHABLANOPE,
                :CDPROCHABAPROPE,   :CDPROCHABFECOPE,       :IDCADPRAPROVORE,
                :IDCADPRPROCEORE,   :IDATIVO,               :NRORGTRAB,
                :NRESTRUTTRAB,      :NRORGFILIAL,           :IDIDIOMA,
                :SGOPERADOR,        :CDSENHAOPERMD5,        :DSHASHALTERASENHA,
                :DSEMAILOPER_BKP,   :DSCRIPTORECSENHA,      :IDCHEFERECEITAM,
                :USR_NRORDEMSETOR,  :NROPERREDE_BKP,        :IDOPERSAAS,
                :DSIMAGEMOPER,      :NRORGOPER,             :IDOPERMASTERZMART,
                :IDOPERMASTERCP,    :CDSENHAOPERSUP,        :NRORGSUP,
                :DTLIMACESSOSUP
            )
SQL;

        $stmt = $this->connection->prepare($sql);
        $stmt->execute($params);
    }
}